@@ -40,19 +40,25 @@ class DatabaseSearch:
         :rtype: str | int | any
         """
         reporter = get_reporter()
-        if cast_to == 'str':
-            reporter.report_debug(f"Casting {value} to string")
-            return str(value)
 
-        if cast_to == 'int':
-            reporter.report_debug(f"Casting {value} to int")
-            return int(value)
+        try:
+            if cast_to == 'str':
+                reporter.report_debug(f"Casting {value} to string")
+                return str(value)
 
+            if cast_to == 'int':
+                reporter.report_debug(f"Casting {value} to int")
+                return int(value)
+
+        except ValueError:
+            reporter.report_debug(f"Value {value} cannot be cast to {cast_to}")
+            
         reporter.report_debug(f"No cast to value set - {cast_to}")
 
         return value
 
 
+
 class CachingDatabaseSearch(DatabaseSearch):
     """
     Implements a caching mechanism for querying and retrieving data from a
